/**
 * Implements settings management
 */

import React, { useState, useEffect, createContext } from 'react';

import backend from 'lib/backend';


export const fetchSettings = async () => {
	let response = await backend("/api/settings");
	return response.body;
}


export const saveSettings = async ({ username, password }) => {
	await backend("/api/settings", "PUT", {
		body: {
			username, 
			password
		}
	});
}


export const defaultCtxValue = {
	fetching: true,
    fetched: false,

    saving: false,

    username: null,
    password: null,

    fetch: () => null,
    save: () => null
};


export const SettingsContext = createContext(defaultCtxValue);


// HoC component
export default (Wrapped) => (props) => {
	const [settings, updateSettings] = useState(defaultCtxValue);

	//wrapped backend calls 
	async function fetch() {
		updateSettings({ ...settings, fetching: true });

		try {
			let response = await fetchSettings();
			updateSettings({ ...settings, ...response, fetching: false, fetched: true });
		} catch (e) {
			updateSettings({ ...settings, fetching: false, fetched: false });
			console.error(e);
		}
	}

	async function save(values) {
		updateSettings({ ...settings, saving: true });
		try {
			let response = await saveSettings(values);
			updateSettings({ ...settings, ...values, saving: false, fetched: true });
		} catch (e) {
			console.error(e);
		}
	}

	//try to fetch settings once the component is mounted
	useEffect(() => {
		fetch();
	}, []);

	return (
		<SettingsContext.Provider value={{ ...settings, fetch, save }}>
			<Wrapped settings={ settings } {...props} />
		</SettingsContext.Provider>
	);

}